@@ -5,4 +5,4 @@ class ProcessStatusType(Enum):
     STARTED = 2
     FINALIZED = 3
     LOCKED = 4
-    NOTAPPROVED = 5
+    NOT_APPROVED = 5
