@@ -1,10 +1,12 @@
 from atk_common.enums.response_status_type_enum import ResponseStatusType
 
-def create_response(status, status_code, response_msg):
+def create_response(status, status_code, response_msg, http_headers=None, content_type='application/json'):
     data = {}
     data['status'] = status
     data['statusCode'] = status_code
     data['responseMsg'] = response_msg
+    data['httpHeaders'] = http_headers
+    data['contentType'] = content_type
     return data
 
 def is_response_ok(response):
