@@ -1,8 +1,8 @@
-from atk_common.datetime_utils import get_utc_date_time
+from atk_common.datetime_utils import get_utc_date_time_str
 from atk_common.http_utils import is_http_status_internal
 
 def create_date_time():
-    date_time = get_utc_date_time()
+    date_time = get_utc_date_time_str()
     return '[' + date_time + '] '
 
 def add_log_item(text):
